---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: lukasschwab
---

# Description
> A clear and concise description of what the bug is.

## Steps to reproduce
> Steps to reproduce the behavior; ideally, include a code snippet.

## Expected behavior
> A clear and concise description of what you expected to happen.

# Versions

<!-- Run `python --version`. -->
+ `python` version:

<!-- Run `pip freeze | grep arxiv`. -->
+ `arxiv.py` version:

# Additional context
> Add any other context about the problem here.
